import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { Dialog, DialogBody, DialogFooter, Classes, Tabs, Tab, } from '@blueprintjs/core';
import { css } from '@emotion/react';
import { Formik } from 'formik';
import { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import { FaBolt, FaPaste, FaRegCopy, FaWrench } from 'react-icons/fa';
import { Toolbar, useOnOff } from 'react-science/ui';
import { ClipboardFallbackModal } from '../../../utils/clipboard/clipboardComponents';
import { useClipboard } from '../../../utils/clipboard/clipboardHooks';
import { usePreferences, useWorkspacesList, } from '../../context/PreferencesContext';
import { useToaster } from '../../context/ToasterContext';
import ActionButtons from '../../elements/ActionButtons';
import Button from '../../elements/Button';
import Label from '../../elements/Label';
import DropDownButton from '../../elements/dropDownButton/DropDownButton';
import { useSaveSettings } from '../../hooks/useSaveSettings';
import { useWorkspaceAction } from '../../hooks/useWorkspaceAction';
import { getPreferencesByWorkspace } from '../../reducer/preferences/utilities/getPreferencesByWorkspace';
import PredefinedWorkspaces from '../../workspaces';
import WorkspaceItem from './WorkspaceItem';
import DatabasesTabContent from './settings-tabs/DatabasesTabContent';
import DisplayTabContent from './settings-tabs/DisplayTabContent';
import GeneralTabContent from './settings-tabs/GeneralTabContent';
import ImportationFiltersTabContent from './settings-tabs/ImportationFiltersTabContent';
import InfoBlockTabContent from './settings-tabs/InfoBlockTabContent';
import NucleiTabContent from './settings-tabs/NucleiTabContent';
import OnLoadProcessingTabContent from './settings-tabs/OnLoadProcessingTabContent';
import SpectraColorsTabContent from './settings-tabs/SpectraColorsTabContent';
import ToolsTabContent from './settings-tabs/ToolsTabContent';
import { validation } from './settingsValidation';
const styles = css `
  .section-header {
    font-size: 13px;
    color: #2ca8ff;
    margin-bottom: 10px;
    border-bottom: 0.55px solid #f9f9f9;
    padding: 6px 2px;
  }

  .label {
    font-size: 12px;
    font-weight: bold;
    margin-right: 10px;
  }

  .input {
    font-size: 14px;
    padding: 3px;
  }

  .checkbox-label {
    min-width: 300px;
    display: inline-block;
  }

  .help-checkbox-element {
    .checkbox-label {
      width: 260px;
    }
  }
`;
function isRestButtonDisable(currentWorkspaceSetting, workspaceName, customWorkspaces) {
    if (!PredefinedWorkspaces[workspaceName] &&
        !customWorkspaces[workspaceName]) {
        return true;
    }
    else {
        return (JSON.stringify(currentWorkspaceSetting) ===
            JSON.stringify(getPreferencesByWorkspace(workspaceName, customWorkspaces)));
    }
}
function GeneralSettingsModal({ height }) {
    const [isOpenDialog, openDialog, closeDialog] = useOnOff(false);
    const { dispatch, current: currentWorkspace, originalWorkspaces, ...preferences } = usePreferences();
    const { addNewWorkspace, removeWorkspace, setActiveWorkspace } = useWorkspaceAction();
    const { saveSettings, SaveSettingsModal } = useSaveSettings();
    const toaster = useToaster();
    const refForm = useRef(null);
    const workspaces = useWorkspacesList();
    const workspaceName = preferences.workspace.current;
    const [isRestDisabled, setRestDisabled] = useState(isRestButtonDisable(currentWorkspace, workspaceName, originalWorkspaces));
    const pastRef = useRef(null);
    const workspacesList = useMemo(() => {
        return workspaces.concat([
            {
                key: 'new',
                label: 'Custom workspace',
            },
        ]);
    }, [workspaces]);
    const handleReset = () => {
        const workSpaceDisplayPreferences = getPreferencesByWorkspace(workspaceName, originalWorkspaces);
        void refForm.current?.setValues(workSpaceDisplayPreferences);
    };
    function submitHandler(values) {
        saveSettings(values);
        closeDialog?.();
    }
    function addWorkSpaceHandler(name) {
        addNewWorkspace(name, refForm.current?.values);
    }
    async function applyPreferencesHandler() {
        const errors = await refForm.current?.validateForm();
        if (Object.keys(errors || {}).length > 0) {
            refForm.current?.handleSubmit();
        }
        else {
            dispatch({
                type: 'APPLY_General_PREFERENCES',
                payload: {
                    data: refForm.current?.values,
                },
            });
            closeDialog?.();
        }
    }
    function deleteWorkSpaceHandler(key) {
        removeWorkspace(key);
    }
    function ChangeWorkspaceHandler(option) {
        setActiveWorkspace(option.key);
    }
    function renderItem(item) {
        return (_jsx(WorkspaceItem, { item: item, onSave: addWorkSpaceHandler, onDelete: deleteWorkSpaceHandler }));
    }
    function handleDisabledRestButton(values) {
        setRestDisabled(isRestButtonDisable(values, workspaceName, originalWorkspaces));
    }
    const { readText, rawWriteWithType, shouldFallback, cleanShouldFallback, text, } = useClipboard();
    function handleCopyWorkspace() {
        const data = { [workspaceName]: refForm.current?.values };
        void rawWriteWithType(JSON.stringify(data)).then(() => {
            toaster.show({
                message: 'Workspace copied to clipboard',
                intent: 'success',
            });
        });
    }
    const setWorkspaceSetting = useCallback((inputWorkspace) => {
        const parseWorkspaceName = Object.keys(inputWorkspace)[0];
        if (preferences.workspace.current === parseWorkspaceName) {
            void refForm.current?.setValues(inputWorkspace[parseWorkspaceName]);
        }
        else if (preferences.workspaces[parseWorkspaceName]) {
            pastRef.current = inputWorkspace;
            dispatch({
                type: 'SET_WORKSPACE',
                payload: {
                    workspace: parseWorkspaceName,
                    workspaceSource: 'any',
                },
            });
        }
    }, [dispatch, preferences.workspace, preferences.workspaces]);
    useEffect(() => {
        if (pastRef.current) {
            setWorkspaceSetting(pastRef.current);
            pastRef.current = null;
        }
    }, [setWorkspaceSetting]);
    function handlePastWorkspace(text) {
        if (!text)
            return;
        try {
            const parseWorkspaces = JSON.parse(text);
            setWorkspaceSetting(parseWorkspaces);
        }
        catch {
            toaster.show({ message: 'object parse error', intent: 'danger' });
        }
        cleanShouldFallback();
    }
    function handlePastWorkspaceAction() {
        void readText().then(handlePastWorkspace);
    }
    return (_jsxs(_Fragment, { children: [_jsx(Toolbar.Item, { id: "general-settings", onClick: openDialog, tooltip: "General settings", icon: _jsx(FaWrench, {}) }), _jsxs(Dialog, { isOpen: isOpenDialog, onClose: closeDialog, style: { maxWidth: 1000, width: '50vw', minWidth: 800 }, title: "General settings", icon: "cog", children: [_jsx("div", { children: _jsxs("div", { className: Classes.DIALOG_HEADER, style: {
                                cursor: 'default',
                                paddingTop: '10px',
                                boxShadow: 'none',
                                backgroundColor: '#f8f8f8',
                            }, children: [_jsx(Label, { title: "Workspace", children: _jsx(DropDownButton, { data: workspacesList, renderItem: renderItem, selectedKey: preferences.workspace.current, onSelect: ChangeWorkspaceHandler }) }), _jsx(Button.Action, { size: "xSmall", onClick: handleReset, toolTip: "Reset workspace preferences", tooltipOrientation: "horizontal", style: {
                                        marginLeft: '10px',
                                    }, disabled: isRestDisabled, children: _jsx(FaBolt, {}) }), _jsx(Button.Done, { size: "xSmall", fill: "outline", onClick: handleCopyWorkspace, toolTip: "Copy workspace preferences", tooltipOrientation: "horizontal", style: {
                                        marginLeft: '10px',
                                    }, children: _jsx(FaRegCopy, {}) }), _jsx(Button.Action, { size: "xSmall", fill: "outline", onClick: handlePastWorkspaceAction, toolTip: "Past workspace preferences", tooltipOrientation: "horizontal", style: {
                                        marginLeft: '10px',
                                    }, children: _jsx(FaPaste, {}) })] }) }), _jsx(DialogBody, { css: css `
            padding: 0;
            background-color: white;
          `, children: _jsx("div", { css: styles, style: { height }, children: _jsx(Formik, { enableReinitialize: true, innerRef: refForm, initialValues: currentWorkspace, validationSchema: validation, onSubmit: submitHandler, validate: handleDisabledRestButton, children: _jsxs(Tabs, { vertical: true, css: css `
                  height: 100%;

                  div[role='tabpanel'] {
                    width: 100%;
                    padding: 0.8rem;
                    overflow: auto;
                    max-height: 100%;
                  }
                `, fill: true, children: [_jsx(Tab, { title: "General", id: "general", panel: _jsx(GeneralTabContent, {}) }), _jsx(Tab, { title: "Nuclei", id: "nuclei", panel: _jsx(NucleiTabContent, {}) }), _jsx(Tab, { title: "Panels", id: "display", panel: _jsx(DisplayTabContent, {}) }), _jsx(Tab, { title: "Tools", id: "tools", panel: _jsx(ToolsTabContent, {}) }), _jsx(Tab, { title: "Databases", id: "databases", panel: _jsx(DatabasesTabContent, { currentWorkspace: workspaceName, originalWorkspaces: originalWorkspaces }) }), _jsx(Tab, { title: "Import filters", id: "importation-filters", panel: _jsx(ImportationFiltersTabContent, {}) }), _jsx(Tab, { title: "Title block", id: "title-block", panel: _jsx(InfoBlockTabContent, {}) }), _jsx(Tab, { title: "Auto processing", id: "on-load-processing", panel: _jsx(OnLoadProcessingTabContent, {}) }), _jsx(Tab, { title: "Spectra colors", id: "spectra-colors", panel: _jsx(SpectraColorsTabContent, {}) })] }) }) }) }), _jsx(DialogFooter, { children: _jsxs("div", { style: { display: 'flex', justifyContent: 'flex-end' }, children: [_jsx(ActionButtons, { style: { flexDirection: 'row-reverse', margin: 0 }, onDone: () => refForm.current?.submitForm(), doneLabel: "Apply and Save", onCancel: () => {
                                        closeDialog?.();
                                    } }), _jsx(Button.Secondary, { style: { margin: '0 10px' }, onClick: applyPreferencesHandler, children: "Apply" })] }) })] }), _jsx(SaveSettingsModal, {}), _jsx(ClipboardFallbackModal, { mode: shouldFallback, onDismiss: cleanShouldFallback, onReadText: handlePastWorkspace, text: text, label: "Workspace" })] }));
}
export default GeneralSettingsModal;
