import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useFormikContext } from 'formik';
import { useCallback, useMemo } from 'react';
import { FaPlus, FaTimes } from 'react-icons/fa';
import Button from '../../../elements/Button';
import { GroupPane } from '../../../elements/GroupPane';
import ReactTable from '../../../elements/ReactTable/ReactTable';
import FormikInput from '../../../elements/formik/FormikInput';
const styles = {
    input: {
        width: '100%',
    },
    column: {
        padding: '2px',
    },
};
function NucleiTabContent() {
    const { values, setFieldValue } = useFormikContext();
    const fields = values?.nuclei || [];
    const addHandler = useCallback((data, index) => {
        let columns = [];
        const emptyField = {
            nucleus: '',
            ppmFormat: '0.00',
            hzFormat: '0.00',
        };
        if (data && Array.isArray(data)) {
            columns = [...data.slice(0, index), emptyField, ...data.slice(index)];
        }
        else {
            columns.push(emptyField);
        }
        void setFieldValue('nuclei', columns);
    }, [setFieldValue]);
    const deleteHandler = useCallback((data, index) => {
        const _fields = data.filter((_, columnIndex) => columnIndex !== index);
        void setFieldValue('nuclei', _fields);
    }, [setFieldValue]);
    const COLUMNS = useMemo(() => [
        {
            Header: '#',
            style: { width: '25px', ...styles.column },
            accessor: (_, index) => index + 1,
        },
        {
            Header: 'Nucleus',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `nuclei.${row.index}.nucleus`, style: { input: styles.input } }));
            },
        },
        {
            Header: 'δ (ppm)',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `nuclei.${row.index}.ppmFormat`, style: { input: styles.input } }));
            },
        },
        {
            Header: 'Coupling (Hz)',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `nuclei.${row.index}.hzFormat`, style: { input: styles.input } }));
            },
        },
        {
            Header: 'Axis from',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `nuclei.${row.index}.axisFrom`, style: { input: styles.input }, type: "number" }));
            },
        },
        {
            Header: 'Axis to',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `nuclei.${row.index}.axisTo`, style: { input: styles.input }, type: "number" }));
            },
        },
        {
            Header: '',
            style: { width: '70px', ...styles.column },
            id: 'add-button',
            Cell: ({ data, row }) => {
                return (_jsxs("div", { style: { display: 'flex', justifyContent: 'space-around' }, children: [_jsx(Button.Done, { fill: "outline", onClick: () => addHandler(data, row.index + 1), children: _jsx(FaPlus, {}) }), _jsx(Button.Danger, { fill: "outline", onClick: () => deleteHandler(data, row.index), children: _jsx(FaTimes, {}) })] }));
            },
        },
    ], [addHandler, deleteHandler]);
    return (_jsx("div", { children: _jsx(GroupPane, { text: "Number formatting for crosshair and info line and axis domain", renderHeader: (text) => {
                return (_jsx(FieldsBlockHeader, { text: text, onAdd: () => addHandler(fields, 0) }));
            }, children: _jsx(ReactTable, { style: {
                    'table, table td, table th': { border: 'none' },
                    'table thead': { borderBottom: '1px solid #f9f9f9' },
                }, data: fields, columns: COLUMNS, emptyDataRowText: "No Nucleus" }) }) }));
}
function FieldsBlockHeader({ onAdd, text }) {
    return (_jsxs("div", { className: "section-header", style: { display: 'flex' }, children: [_jsx("p", { style: { flex: 1 }, children: text }), _jsx(Button.Done, { fill: "outline", size: "xSmall", onClick: onAdd, children: "Add nuclei preferences" })] }));
}
export default NucleiTabContent;
