import { xyIntegration } from 'ml-spectra-processing';
import { mapRanges } from 'nmr-processing';
import detectSignals from './detectSignals';
export function cutRange(spectrum, x) {
    const cutRanges = {};
    for (const range of spectrum?.ranges?.values || []) {
        const { to, from, id } = range;
        if (x > from && x < to) {
            const leftRange = createRange(spectrum, { from, to: x });
            const rightRange = createRange(spectrum, {
                from: x,
                to,
            });
            cutRanges[id] = [];
            if (leftRange) {
                cutRanges[id].push(leftRange);
            }
            if (rightRange) {
                cutRanges[id].push(rightRange);
            }
        }
    }
    return cutRanges;
}
export function createRange(spectrum, options) {
    const { from, to, logger } = options;
    const { x, re: y } = spectrum.data;
    const { nucleus, originFrequency: frequency } = spectrum.info;
    const absolute = xyIntegration({ x, y }, { from, to });
    const signals = detectSignals({ x, y }, {
        logger,
        from,
        to,
        nucleus,
        frequency,
    }) || [];
    const range = {
        from,
        to,
        absolute,
        signals: signals,
    };
    try {
        const [newRange] = mapRanges([range], spectrum);
        return newRange;
    }
    catch (error) {
        reportError(error);
        logger?.error('Could not calculate the multiplicity');
    }
}
